==> hawkular-accounts-api-1.0.9.Final-sources.jar: org/hawkular/accounts/api/PermissionService.java <==
/*
 * Copyright 2015 Red Hat, Inc. and/or its affiliates
 * and other contributors as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.hawkular.accounts.api;

import java.util.Set;

import org.hawkular.accounts.api.model.Operation;
import org.hawkular.accounts.api.model.Permission;
import org.hawkular.accounts.api.model.Role;

/**
 * Service providing access to permission-related queries. Can be injected via CDI into managed beans as follows:
 * <p>
 *     <pre>
 *         &#64;Inject PermissionService permissionService;
 *     </pre>
 * </p>
 * Concrete implementations do not hold any state, but it's advised to get an instance through CDI or as an EJB.
 *
 * @author Juraci Paixão Kröhling
 */
public interface PermissionService {

    /**
     * Provides a list of roles that have permission to perform the given operation.
     *
     * @param operation    the operation
     * @return a list of roles
     */
    Set<Role> getPermittedRoles(Operation operation);

    /**
     * Provides a list of Permissions that exists for the given operation
     * @param operation    the operation
     * @return a list of permissions
     */
    Set<Permission> getPermissionsForOperation(Operation operation);
}

==> hawkular-accounts-api-2.0.11.Final-sources.jar: org/hawkular/accounts/api/PermissionService.java <==
/*
 * Copyright 2015 Red Hat, Inc. and/or its affiliates
 * and other contributors as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.hawkular.accounts.api;

import java.util.Set;
import java.util.UUID;

import org.hawkular.accounts.api.model.Operation;
import org.hawkular.accounts.api.model.Permission;
import org.hawkular.accounts.api.model.Role;

/**
 * Service providing access to permission-related queries. Can be injected via CDI into managed beans as follows:
 * <p>
 *     <pre>
 *         &#64;Inject PermissionService permissionService;
 *     </pre>
 * </p>
 * Concrete implementations do not hold any state, but it's advised to get an instance through CDI or as an EJB.
 *
 * @author Juraci Paixão Kröhling
 */
public interface PermissionService {

    /**
     * Provides a list of roles that have permission to perform the given operation.
     *
     * @param operation    the operation
     * @return a list of roles
     */
    Set<Role> getPermittedRoles(Operation operation);

    /**
     * Provides a list of Permissions that exists for the given operation
     * @param operation    the operation
     * @return a list of permissions
     */
    Set<Permission> getPermissionsForOperation(Operation operation);

    /**
     * Retrieves an existing Permission based on its ID
     * @param id    the ID of the permission
     * @return the permission or null
     */
    Permission getById(UUID id);

    /**
     * Creates a permission composed of the given operation and role
     * @param operation    the operation
     * @param role         the allowed role for the permission
     * @return  the newly created permission
     */
    Permission create(Operation operation, Role role);

    /**
     * Removes the given permission from the data store.
     * @param permission the permission to be removed.
     */
    void remove(Permission permission);
}
